@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub name { 'kqueue' }
 
@@ -99,6 +99,20 @@ sub gen_add_pool_notify {
             ->line("kevent($loop_var, &ev, 1, NULL, 0, NULL);");
 }
 
+# Multi-pool integration - add all pool notify fds to kqueue
+sub gen_add_multi_pool_notify {
+    my ($class, $builder, $loop_var, $pool_slots_var, $pool_count_var) = @_;
+
+    $builder->line("/* Add all pool notify fds to kqueue */")
+            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    int _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
+            ->line("    if (_pool_notify_fd >= 0) {")
+            ->line("        EV_SET(&ev, _pool_notify_fd, EVFILT_READ, EV_ADD | EV_ENABLE, 0, 0, NULL);")
+            ->line("        kevent($loop_var, &ev, 1, NULL, 0, NULL);")
+            ->line("    }")
+            ->line("}");
+}
+
 1;
 
 __END__
