@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Hypersonic::Event::Role - Base class for event backends
 #
@@ -89,7 +89,7 @@ sub gen_cleanup {
 }
 
 # ============================================================
-# Future/Pool Integration Methods
+# Future/Pool Integration Methods (Single Pool - Legacy)
 # ============================================================
 
 # Generate code to add the Future pool notify fd to the event loop
@@ -115,6 +115,49 @@ sub gen_process_pool_ready {
             ->line('xs_pool_process_ready(aTHX_ NULL);');
 }
 
+# ============================================================
+# Multi-Pool Integration Methods (OO API)
+# ============================================================
+
+# Generate code to add multiple pool notify fds to the event loop
+# pool_slots is an array variable, pool_count is the count
+sub gen_add_multi_pool_notify {
+    my ($class, $builder, $loop_var, $pool_slots_var, $pool_count_var) = @_;
+
+    $builder->line("/* Add all pool notify fds to event loop */")
+            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    int _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
+            ->line("    if (_pool_notify_fd >= 0) {");
+
+    # Use the backend's gen_add method - inline the generated code
+    $class->gen_add($builder, $loop_var, '_pool_notify_fd');
+
+    $builder->line("    }")
+            ->line("}");
+}
+
+# Generate code to check if fd matches any pool's notify_fd
+# Sets matched_slot_var to the pool slot if matched, -1 otherwise
+sub gen_check_multi_pool_notify {
+    my ($class, $builder, $fd_var, $pool_slots_var, $pool_count_var, $matched_slot_var) = @_;
+
+    $builder->line("int $matched_slot_var = -1;")
+            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    int _pslot = $pool_slots_var\[_pi];")
+            ->line("    if ($fd_var == pool_get_notify_fd_slot(_pslot)) {")
+            ->line("        $matched_slot_var = _pslot;")
+            ->line("        break;")
+            ->line("    }")
+            ->line("}");
+}
+
+# Generate code to process a specific pool's completed operations
+sub gen_process_pool_slot {
+    my ($class, $builder, $slot_var) = @_;
+    $builder->line("/* Process completed async operations for pool slot */")
+            ->line("pool_process_ready_slot($slot_var);");
+}
+
 # ============================================================
 # Utility Methods for Backends
 # ============================================================
