@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # High-performance JIT-compiled Future for async operations
 # Serves as the foundation for all async in Hypersonic:
@@ -13,6 +13,7 @@ our $VERSION = '0.06';
 # - Timers, file I/O, etc.
 
 use XS::JIT::Builder;
+use Hypersonic::JIT::Util;
 
 # Future states
 use constant {
@@ -129,20 +130,12 @@ sub generate_c_code {
     my $max_futures = $opts->{max_futures} // MAX_FUTURES;
     my $max_callbacks = $opts->{max_callbacks} // MAX_CALLBACKS;
 
-    # System includes
-    $builder->line('#include <stdlib.h>')
-            ->line('#include <string.h>')
-            ->line('#include <pthread.h>')
-            ->line('#include <unistd.h>')
-            ->line('#include <fcntl.h>')
-            ->line('#include <errno.h>')
-            ->blank;
+    # PERL_VERSION_* macros are already provided by XS::JIT preamble
+    # No need to emit them here
 
-    # Platform-specific notification
-    $builder->line('#ifdef __linux__')
-            ->line('#include <sys/eventfd.h>')
-            ->line('#endif')
-            ->blank;
+    # System includes via centralized utility
+    Hypersonic::JIT::Util->add_standard_includes($builder,
+        qw(unistd fcntl threading eventfd));
 
     # Defines
     $builder->line("#define MAX_FUTURES $max_futures")
@@ -279,22 +272,31 @@ sub _gen_custom_ops {
             ->ck_end;
 
     # Register checkers function
+    # cv_set_call_checker requires Perl 5.14+ - check at JIT time, not C compile time
     $builder->xs_function('xs_register_custom_ops')
             ->xs_preamble
-            ->line('CV *custom_cv;')
             ->line('register_xop_future_is_done_xop(aTHX);')
             ->line('register_xop_future_is_ready_xop(aTHX);')
             ->line('register_xop_future_is_failed_xop(aTHX);')
-            ->line('register_xop_future_is_cancelled_xop(aTHX);')
-            ->line('custom_cv = get_cv("Hypersonic::Future::is_done", 0);')
-            ->line('if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_done, &PL_sv_undef);')
-            ->line('custom_cv = get_cv("Hypersonic::Future::is_ready", 0);')
-            ->line('if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_ready, &PL_sv_undef);')
-            ->line('custom_cv = get_cv("Hypersonic::Future::is_failed", 0);')
-            ->line('if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_failed, &PL_sv_undef);')
-            ->line('custom_cv = get_cv("Hypersonic::Future::is_cancelled", 0);')
-            ->line('if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_cancelled, &PL_sv_undef);')
-            ->xs_return('0')
+            ->line('register_xop_future_is_cancelled_xop(aTHX);');
+
+    # JIT optimization: only emit cv_set_call_checker code if Perl >= 5.14
+    # This eliminates dead code from the generated C file on older Perls
+    if ($] >= 5.014000) {
+        $builder->line('{')
+                ->line('    CV *custom_cv;')
+                ->line('    custom_cv = get_cv("Hypersonic::Future::is_done", 0);')
+                ->line('    if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_done, &PL_sv_undef);')
+                ->line('    custom_cv = get_cv("Hypersonic::Future::is_ready", 0);')
+                ->line('    if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_ready, &PL_sv_undef);')
+                ->line('    custom_cv = get_cv("Hypersonic::Future::is_failed", 0);')
+                ->line('    if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_failed, &PL_sv_undef);')
+                ->line('    custom_cv = get_cv("Hypersonic::Future::is_cancelled", 0);')
+                ->line('    if (custom_cv) cv_set_call_checker(custom_cv, S_ck_ck_future_is_cancelled, &PL_sv_undef);')
+                ->line('}');
+    }
+
+    $builder->xs_return('0')
             ->xs_end;
 }
 
@@ -1282,7 +1284,7 @@ sub compile {
 
     require XS::JIT;
 
-    my $cache_dir = $opts{cache_dir} // '_hypersonic_future_cache';
+    my $cache_dir = $opts{cache_dir} // '_hypersonic_cache/future';
     $MODULE_NAME = 'Hypersonic::Future::XS_' . $$;
 
     my $builder = XS::JIT::Builder->new;
@@ -1310,6 +1312,7 @@ sub compile {
 
     # Register custom ops to replace method calls at compile time
     $class->_register_ops();
+    Hypersonic::Future::Pool->_register_ops();
 
     # Install direct XS function aliases - eliminates Perl wrapper overhead
     no warnings 'redefine';
