@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # JIT-compiled Request object using array-based slots for maximum speed
 # Generates XS accessors at compile time via XS::JIT::Builder
@@ -46,13 +46,19 @@ our @EXPORT_OK = qw(
 my $COMPILED = 0;
 my $MODULE_ID = 0;
 
+# Unified compile interface
+sub compile {
+    my ($class, %opts) = @_;
+    return $class->compile_accessors(%opts);
+}
+
 # Generate and compile XS accessors
 sub compile_accessors {
     my ($class, %opts) = @_;
 
-    return if $COMPILED;
+    return 1 if $COMPILED;
 
-    my $cache_dir = $opts{cache_dir} // '_hypersonic_request_cache';
+    my $cache_dir = $opts{cache_dir} // '_hypersonic_cache/request';
     my $module_name = 'Hypersonic::Request::Accessors_' . $MODULE_ID++;
 
     my $builder = XS::JIT::Builder->new;
