@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Session management for Hypersonic
 # Uses signed cookies for session ID, memory store for data
@@ -12,6 +12,7 @@ our $VERSION = '0.06';
 # Only activated when session_config() is called
 
 use Digest::SHA qw(hmac_sha256_hex);
+use Hypersonic::JIT::Util;
 
 # Session slot constants (used in Request object)
 use constant {
@@ -38,6 +39,12 @@ my $MODULE_ID = 0;
 # JIT Compilation of Cryptographic Operations
 # ============================================================
 
+# Unified compile interface
+sub compile {
+    my ($class, %opts) = @_;
+    return $class->compile_session_ops(%opts);
+}
+
 sub compile_session_ops {
     my ($class, %opts) = @_;
 
@@ -68,19 +75,14 @@ sub compile_session_ops {
         return 0;
     }
 
-    my $cache_dir = $opts{cache_dir} // '_hypersonic_session_cache';
+    my $cache_dir = $opts{cache_dir} // '_hypersonic_cache/session';
     my $module_name = 'Hypersonic::Session::Ops_' . $MODULE_ID++;
 
     my $builder = XS::JIT::Builder->new;
 
-    # Add required includes
-    $builder->line('#include <openssl/hmac.h>')
-            ->line('#include <openssl/evp.h>')
-            ->line('#include <openssl/rand.h>')
-            ->line('#include <fcntl.h>')
-            ->line('#include <unistd.h>')
-            ->line('#include <string.h>')
-            ->blank;
+    # Add required includes via centralized utility
+    Hypersonic::JIT::Util->add_standard_includes($builder,
+        qw(unistd fcntl openssl));
 
     # --------------------------------------------------------
     # jit_hmac_sha256_hex: Generate HMAC-SHA256 signature
