@@ -4,10 +4,11 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use XS::JIT;
 use XS::JIT::Builder;
+use Hypersonic::JIT::Util;
 
 # Platform detection
 sub platform {
@@ -28,29 +29,26 @@ sub event_backend {
 my $COMPILED = 0;
 my $MODULE_ID = 0;
 
+# Unified compile interface
+sub compile {
+    my ($class, %opts) = @_;
+    return $class->compile_socket_ops(%opts);
+}
+
 # Generate and compile JIT socket functions using Builder
 sub compile_socket_ops {
     my ($class, %opts) = @_;
 
-    return if $COMPILED;
+    return 1 if $COMPILED;
 
-    my $cache_dir = $opts{cache_dir} // '_hypersonic_socket_cache';
+    my $cache_dir = $opts{cache_dir} // '_hypersonic_cache/socket';
     my $module_name = 'Hypersonic::Socket::Ops_' . $MODULE_ID++;
 
     my $builder = XS::JIT::Builder->new;
 
-    # Common includes (socket operations only - no event loop headers)
-    $builder->line('#include <stdio.h>')
-      ->line('#include <stdlib.h>')
-      ->line('#include <string.h>')
-      ->line('#include <unistd.h>')
-      ->line('#include <fcntl.h>')
-      ->line('#include <errno.h>')
-      ->line('#include <sys/socket.h>')
-      ->line('#include <sys/types.h>')
-      ->line('#include <netinet/in.h>')
-      ->line('#include <arpa/inet.h>')
-      ->line('#include <sys/uio.h>');
+    # Common includes via centralized utility
+    Hypersonic::JIT::Util->add_standard_includes($builder,
+        qw(stdio unistd fcntl socket));
 
     $builder->line('#define RECV_BUF_SIZE 65536')
       ->blank
