@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # JIT-compiled TLS/HTTPS support for Hypersonic
 # Uses OpenSSL for TLS support (via Alien::OpenSSL when available)
@@ -68,13 +68,19 @@ C
     return 0;
 }
 
+# Unified compile interface
+sub compile {
+    my ($class, %opts) = @_;
+    return $class->compile_tls_ops(%opts);
+}
+
 # Compile TLS ops using XS::JIT::Builder
 sub compile_tls_ops {
     my ($class, %opts) = @_;
 
-    return if $COMPILED;
+    return 1 if $COMPILED;
 
-    my $cache_dir = $opts{cache_dir} // '_hypersonic_tls_cache';
+    my $cache_dir = $opts{cache_dir} // '_hypersonic_cache/tls';
     my $module_name = 'Hypersonic::TLS::Ops_' . $MODULE_ID++;
 
     my $builder = XS::JIT::Builder->new;
